@@ -35,7 +35,7 @@ def main():
 
 def getSeries(path_to_series):
     '''Create a series object, fully populated.'''
-    if path_to_series.find(os.sep) < 0:
+    if path_to_series.find('/') < 0: #=== problem here in Windows, adds multiple './' os.sep
         path_to_series = './' + path_to_series
     series = getSeriesXML(path_to_series)
     series.getSectionsXML(path_to_series)
